==> localnews-user-api-1.0.4-sources.jar: com/bxm/localnews/user/controller/RedPackController.java <==
package com.bxm.localnews.user.controller;

import java.math.BigDecimal;

import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.BasicParam;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.user.dto.UserRedPacketDTO;
import com.bxm.localnews.user.service.RedPacketService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author zhaoyadong 2019/3/4 19:00
 * @desc
 */
@Api(tags = "9-09 用户领取红包", description = "领取红包相关操作")
@RestController
@RequestMapping("api/red/packet")
public class RedPackController {

    @Autowired
    private RedPacketService redPacketService;

    @ApiOperation(value = "9-09-1 用户领取红包", notes = "用户领取红包")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id"),
            @ApiImplicitParam(name = "areaCode", value = "地区编码(12位地区编码)")
    })
    @PostMapping("")
    public Json<BigDecimal> userRecieveRedPacket(BasicParam basicParam, @RequestParam("userId") Long userId,
                                                 @RequestParam("areaCode") String areaCode) {
        return this.redPacketService.userRecieveRedPacket(userId, basicParam, areaCode);
    }

    @ApiOperation(value = "9-09-2 获取对应地区是否开启红包", notes = "判断用户是否满足领取新人红包条件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id"),
            @ApiImplicitParam(name = "areaCode", value = "地区编码(12位地区编码)")
    })
    @GetMapping("/enable")
    public Json<UserRedPacketDTO> enableRedPacket(BasicParam basicParam, @RequestParam("userId") Long userId,
                                                  @RequestParam("areaCode") String areaCode) {
        return ResultUtil.genSuccessResult(this.redPacketService.enableRedPacket(basicParam, userId, areaCode));
    }
}

==> localnews-user-api-1.0.7-sources.jar: com/bxm/localnews/user/controller/RedPackController.java <==
package com.bxm.localnews.user.controller;

import java.math.BigDecimal;

import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.BasicParam;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.user.dto.UserRedPacketDTO;
import com.bxm.localnews.user.service.RedPacketService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author zhaoyadong 2019/3/4 19:00
 * @desc
 */
@Api(tags = "9-09 用户领取红包", description = "领取红包相关操作")
@RestController
@RequestMapping("api/red/packet")
public class RedPackController {

    @Autowired
    private RedPacketService redPacketService;

    @ApiOperation(value = "9-09-1 用户领取红包", notes = "用户领取红包")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id"),
            @ApiImplicitParam(name = "areaCode", value = "地区编码(12位地区编码)")
    })
    @PostMapping("")
    public Json<BigDecimal> userRecieveRedPacket(BasicParam basicParam, @RequestParam("userId") Long userId,
                                                 @RequestParam("areaCode") String areaCode) {
        return this.redPacketService.userRecieveRedPacket(userId, basicParam, areaCode);
    }

    @ApiOperation(value = "9-09-2 获取对应地区是否开启红包", notes = "判断用户是否满足领取新人红包条件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id"),
            @ApiImplicitParam(name = "areaCode", value = "地区编码(12位地区编码)")
    })
    @GetMapping("/enable")
    public Json<UserRedPacketDTO> enableRedPacket(BasicParam basicParam, @RequestParam("userId") Long userId,
                                                  @RequestParam("areaCode") String areaCode) {
        return ResultUtil.genSuccessResult(this.redPacketService.enableRedPacket(basicParam.getDevcId(), userId, areaCode));
    }
}
